@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: comboboxtext.cc,v 1.2 2003/10/18 15:35:30 murrayc Exp $ */
+/* $Id: comboboxtext.cc,v 1.4 2004/05/14 17:11:53 murrayc Exp $ */
 
 /* 
  *
@@ -30,24 +30,10 @@
 namespace Gtk
 {
 
-//TODO: This will not work because:
-// comboboxtext.cc:36: warning: base initializer for `Gtk::ComboBox'
-// comboboxtext.cc:36: warning: will be re-ordered to precede member
-//I have reorderd them myself now to avoid the warning, but this will segfault. murrayc.
 ComboBoxText::ComboBoxText()
-: Gtk::ComboBox(Gtk::ListStore::create(*m_text_columns)), //Create a default treemodel. We must create it in the initializer list, because it is a construct-only property.
-  m_text_columns(new TextModelColumns) //Allocate it dynamically so that it is guarranteed to be created at this point, so we can pass it to the base constructor.
 {
-  Glib::RefPtr<TreeModel> model = get_model(); //Get the model that we just created in the initializer list.
-
-  //TODO: Do some template magic to auto-select and connect the cellrenderer.
-  //Maybe generalise the TreeView template stuff.
-  
-  Gtk::CellRenderer* renderer = Gtk::manage( new Gtk::CellRendererText() );
-  pack_start(*renderer);
-
- //TODO:
-  gtk_cell_layout_set_attributes( GTK_CELL_LAYOUT(gobj()), renderer->gobj(), "text", 0, 0);
+  set_model( Gtk::ListStore::create(m_text_columns) );
+  pack_start(m_text_columns.m_column);
 }
 
 void ComboBoxText::append_text(const Glib::ustring& text)
@@ -70,13 +56,11 @@ Glib::ustring ComboBoxText::get_active_text() const
   Glib::ustring result;
 
   //Get the active row:
-  unsigned int active_row = get_active();
-  Glib::RefPtr<const Gtk::TreeModel> model = get_model();
-  const Gtk::TreeModel::Children& children = model->children();
-  if(active_row < children.size())
+  TreeModel::iterator active_row = get_active();
+  if(active_row)
   {
-    Gtk::TreeModel::Row row = children[active_row];
-    result = row[m_text_columns->m_column];
+    Gtk::TreeModel::Row row = *active_row;
+    result = row[m_text_columns.m_column];
   }
 
   return result;
